import { Getter, Provider, Setter } from '@loopback/core';
import { Request } from '@loopback/rest';
import { UserProfile } from '@loopback/security';
import { AuthenticateFn, AuthenticationStrategy } from '../types';
/**
 * Provides the authentication action for a sequence
 * @example `context.bind('authentication.actions.authenticate').toProvider(AuthenticateActionProvider)`
 */
export declare class AuthenticateActionProvider implements Provider<AuthenticateFn> {
    readonly getStrategy: Getter<AuthenticationStrategy>;
    readonly setCurrentUser: Setter<UserProfile>;
    readonly setRedirectUrl: Setter<string>;
    readonly setRedirectStatus: Setter<number>;
    constructor(getStrategy: Getter<AuthenticationStrategy>, setCurrentUser: Setter<UserProfile>, setRedirectUrl: Setter<string>, setRedirectStatus: Setter<number>);
    /**
     * @returns authenticateFn
     */
    value(): AuthenticateFn;
    /**
     * The implementation of authenticate() sequence action.
     * @param request - The incoming request provided by the REST layer
     */
    action(request: Request): Promise<UserProfile | undefined>;
}
